@@ -19,24 +19,24 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 __all__ = [
     'Constants',
     'dd',
     'Object',
     'Config',
-    'config',
     'CheckType',
-    'Utils',
-    'SyspassClient'
+    'Libs',
+    'SyspassClient',
+    'Api'
 ]
 
 from syspassclient.constants import Constants
 from syspassclient.constants import dd
 from syspassclient.object import Object
-from syspassclient.api import SyspassApi
-from syspassclient.config import Config
-config = Config()
+from syspassclient.api import Api
 from syspassclient.check_type import CheckType
-from syspassclient.utils import Utils
+from syspassclient.libs import Libs
+from syspassclient.config import Config
 from syspassclient.syspassclient import SyspassClient
 
