@@ -20,22 +20,19 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
-import os
-from colorama import init, Fore, Style
-import syspassclient
 
-from yaml import load, dump
+import os
+
+from yaml import load
 
 try:
     from yaml import CLoader as Loader, CDumper as Dumper
 except ImportError:
     from yaml import Loader, Dumper
-init(autoreset=True)
 
 
-class SyspassApi(syspassclient.Object):
+class Api(object):
     def __init__(self):
-        syspassclient.Object.__init__(self)
         self.__api_directory = None
         self.__api_filename = None
         self.__api_filename_ext = None
@@ -98,7 +95,6 @@ class SyspassApi(syspassclient.Object):
             raise TypeError('"version" must be a str type or None')
         if self.api_version != version:
             self.__api_version = version
-            self.read_api()
 
     @property
     def api_url(self):
@@ -109,8 +105,8 @@ class SyspassApi(syspassclient.Object):
 
     @api_url.setter
     def api_url(self, value=None):
-        if type(value) != str:
-            raise TypeError('"version" must be a str type')
+        if value is not None and type(value) != str:
+            raise TypeError('"version" must be a str type or None')
         if self.__api_url != value:
             self.__api_url = value
 
@@ -190,16 +186,8 @@ class SyspassApi(syspassclient.Object):
         """
         Read the API file
         """
-
-        # if api_file is None:
-        #     api_file = self.api_file
-
         with open(self.api_file) as f:
             self.api_data = load(f, Loader=Loader)
             f.close()
 
-            if self.debug and self.debug_level > 2:
 
-                for line in dump(self.api_data).split("\n"):
-                    if self.verbose and self.verbose_level > 2:
-                        print(Fore.CYAN + Style.BRIGHT + "< " + Fore.RESET + Style.RESET_ALL + str(line))
