@@ -20,15 +20,13 @@
 #
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-# python 3 headers, required if submitting to Ansible
-
 import syspassclient
 
 from colorama import init, Fore, Style
+
 init(autoreset=True)
 
 import requests
-requests.urllib3.disable_warnings()
 
 from json.decoder import JSONDecodeError
 
@@ -40,6 +38,7 @@ except ImportError:
     from yaml import Loader, Dumper
 
 import threading
+
 lock = threading.Lock()
 
 
@@ -54,48 +53,85 @@ class Singleton(type):
         return cls._instances[cls]
 
 
-class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singleton):
-    def __init__(self):
-        syspassclient.Object.__init__(self)
-        syspassclient.Utils.__init__(self)
+class SyspassClient(syspassclient.Config, metaclass=Singleton):
+    def __init__(self,
+                 use_by_lookup=None,
+                 api_url=None,
+                 api_version=None,
+                 authToken=None,
+                 tokenPass=None,
+                 verify_ssl=None,
+                 debug=None,
+                 debug_level=None,
+                 verbose=None,
+                 verbose_level=None,
+
+                 ):
+        syspassclient.Config.__init__(self)
 
         # Private property's
+        self.__version = None
+        self.version = '0.5.9'
+
         self.__r_id = None
-
         # Initialize
-        self.__config = None
-        self.config = syspassclient.config
-
-        self.debug = self.config.debug
-        self.debug_level = self.config.debug_level
-        self.verbose = self.config.verbose
-        self.verbose_level = self.config.verbose_level
-
         self.r_id = 1
 
+        # Look init var have been set
+        if use_by_lookup:
+            self.use_by_lookup = use_by_lookup
+        if api_url:
+            self.api_url = api_url
+        if api_version:
+            self.api_version = api_version
+        if authToken:
+            self.authToken = authToken
+        if tokenPass:
+            self.tokenPass = tokenPass
+        if verify_ssl:
+            self.verify_ssl = verify_ssl
+        if debug:
+            self.debug = debug
+        if debug_level:
+            self.debug_level = debug_level
+        if verbose:
+            self.verbose = verbose
+        if verbose_level:
+            self.verbose_level = verbose_level
+
+        print(Fore.YELLOW + Style.BRIGHT + "{0}: ".format(self.__class__.__name__.upper()), end='')
+        print(Fore.WHITE + Style.BRIGHT + "{0} {1}".format("Version ", self.version))
+
+        self.config_read_file()
+        if self.debug and self.debug_level > 2:
+            self.display_resume()
+
+        # In case get default config from Config class
+        # self.debug = self.debug
+        # self.debug_level = self.debug_level
+        # self.verbose = self.verbose
+        # self.verbose_level = self.verbose_level
+
     @property
-    def config(self):
+    def version(self):
         """
-        Store config object, as a property
+        Return version or the syspassclient
 
-        :return: The configuration object
-        :rtype: Config or None
+        :return: the version
+        :return: str
         """
-        return self.__config
+        return self.__version
 
-    @config.setter
-    def config(self, value=None):
+    @version.setter
+    def version(self, version):
         """
-        Set the ``config`` property value
+        Set the ``version`` property value
 
-        :param value: a config instance or None
-        :type value: Config or None
-        :raise TypeError: When ``config`` value is not a Config instance or None
+        :param version: the version
+        :type version: str
         """
-        if value is not None and not isinstance(value, syspassclient.Config):
-            raise TypeError('"config" value must be a syspassclient.Config instance')
-        if self.config != value:
-            self.__config = value
+        if self.__version is None:
+            self.__version = version
 
     def make_post_request(self, data=None, verify=None):
         """
@@ -109,7 +145,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :rtype: dict
         """
         if verify is None:
-            verify = self.config.verify_ssl
+            verify = self.verify_ssl
 
         if self.verbose:
             print(Fore.YELLOW + Style.BRIGHT + "{0}: ".format(self.__class__.__name__.upper()), end='')
@@ -119,7 +155,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
                     print(Fore.GREEN + Style.BRIGHT + "> " + Fore.RESET + Style.RESET_ALL + str(line))
             print(Fore.RESET + Style.RESET_ALL, end='')
 
-        request = requests.post(url=self.config.api_url, json=data, verify=verify)
+        request = requests.post(url=self.api_url, json=data, verify=verify)
 
         try:
             return request.json()
@@ -149,7 +185,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
 
         That function clean the request and mitigate python reserved name, like **Global**, **Id**, **Pass**
 
-        For paramaters list take a look on SysPass API:
+        For parameter's list take a look on SysPass API:
         * https://syspass-doc.readthedocs.io/en/3.0/application/api.html
         * https://syspass-doc.readthedocs.io/en/3.1/application/api.html
 
@@ -157,11 +193,11 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :type parameters: keys
         :return: The parameters format in valid JSON 2.0
         :rtype: str
-        :raise KeyError: When parameters dont contain a key name "method"
+        :raise KeyError: When parameters don't contain a key name "method"
         """
 
-        if "method" not in parameters:
-            raise (KeyError('"parameters" must have a key name "method"'))
+        # if "method" not in parameters:
+        #     raise (KeyError('"parameters" must have a key name "method"'))
         method = parameters["method"]
         del parameters["method"]
 
@@ -285,7 +321,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :rtype: str in case of success or None if nothing found
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         # Exit as soon of possible
         self.look_for_args(
@@ -368,7 +404,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :type account_id: int
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         # Exit as soon of possible
         self.look_for_args(method=method, authToken=authToken, account_id=account_id)
@@ -409,10 +445,10 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :type account_id: int
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         if tokenPass is None:
-            tokenPass = self.config.tokenPass
+            tokenPass = self.tokenPass
 
         self.look_for_args(method=method, authToken=authToken, tokenPass=tokenPass, account_id=account_id)
 
@@ -456,10 +492,10 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :type details: int or None
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         if tokenPass is None:
-            tokenPass = self.config.tokenPass
+            tokenPass = self.tokenPass
 
         self.look_for_args(
             method=method,
@@ -569,10 +605,10 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :type expireDate: int
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         if tokenPass is None:
-            tokenPass = self.config.tokenPass
+            tokenPass = self.tokenPass
 
         if expireDate == "":  # pragma: no cover
             expireDate = None
@@ -634,7 +670,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         count is the number of results.
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         self.look_for_args(method=method, authToken=authToken, text=text, count=count)
 
@@ -682,7 +718,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :type description: str
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         self.look_for_args(method=method, authToken=authToken, name=name, description=description)
 
@@ -712,7 +748,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         cid 	    int 	yes 	    Category’s Id
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         self.look_for_args(method=method, authToken=authToken, cid=cid)
 
@@ -742,7 +778,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         count 	    int 	no 	        Number of results to display
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         self.look_for_args(method=method, authToken=authToken, text=text, count=count)
 
@@ -780,7 +816,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :type Global: int
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         if Global is not None:
             Global = int(bool(Global))
@@ -820,7 +856,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :type cid: int
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         self.look_for_args(method=method, authToken=authToken, cid=cid)
 
@@ -857,7 +893,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :type text: str
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         self.look_for_args(method=method, authToken=authToken, text=text)
 
@@ -901,10 +937,10 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :type tagid: int
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         if tokenPass is None:
-            tokenPass = self.config.tokenPass
+            tokenPass = self.tokenPass
 
         self.look_for_args(method=method, authToken=authToken, tokenPass=tokenPass, tagid=tagid)
 
@@ -942,7 +978,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :type name: str
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         self.look_for_args(method=method, authToken=authToken, name=name)
 
@@ -961,14 +997,6 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
 
         return self.tag_search(text=name)
 
-        # if self.config.rw:
-        #     return self.tag_search(text=name)
-        # else:
-        #     to_return = self.tag_search(text=name)
-        #     if to_return is None:
-        #         raise ValueError('impossible to creat the tag')
-        #     return to_return
-
     def tag_delete(self, method='tag/delete', authToken=None, tagid=None):
         """
         tag/delete
@@ -987,7 +1015,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :type tagid: int
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         self.look_for_args(method=method, authToken=authToken, tagid=tagid)
 
@@ -1034,7 +1062,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :type usersId: list
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         self.look_for_args(method=method, authToken=authToken, name=name, description=description, usersId=usersId)
         data = self.generate_json(
@@ -1063,7 +1091,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         """
 
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         self.look_for_args(method=method, authToken=authToken, text=text, count=count)
         data = self.generate_json(method=method, authToken=authToken, text=text, count=count)
@@ -1119,7 +1147,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         :type ugid: int
         """
         if authToken is None:
-            authToken = self.config.authToken
+            authToken = self.authToken
 
         self.look_for_args(method=method, authToken=authToken, ugid=ugid)
         data = self.generate_json(method=method, authToken=authToken, ugid=ugid)
